package com.ruoyi.mall.mapper;

import java.util.List;
import com.ruoyi.mall.domain.MallMemberMoneyRecord;

/**
 * 会员金额记录Mapper接口
 * 
 * @author chang
 * @date 2021-11-25
 */
public interface MallMemberMoneyRecordMapper 
{
    /**
     * 查询会员金额记录
     * 
     * @param id 会员金额记录主键
     * @return 会员金额记录
     */
    public MallMemberMoneyRecord selectMallMemberMoneyRecordById(Long id);

    /**
     * 查询会员金额记录列表
     * 
     * @param mallMemberMoneyRecord 会员金额记录
     * @return 会员金额记录集合
     */
    public List<MallMemberMoneyRecord> selectMallMemberMoneyRecordList(MallMemberMoneyRecord mallMemberMoneyRecord);

    /**
     * 新增会员金额记录
     * 
     * @param mallMemberMoneyRecord 会员金额记录
     * @return 结果
     */
    public int insertMallMemberMoneyRecord(MallMemberMoneyRecord mallMemberMoneyRecord);

    /**
     * 修改会员金额记录
     * 
     * @param mallMemberMoneyRecord 会员金额记录
     * @return 结果
     */
    public int updateMallMemberMoneyRecord(MallMemberMoneyRecord mallMemberMoneyRecord);

    /**
     * 删除会员金额记录
     * 
     * @param id 会员金额记录主键
     * @return 结果
     */
    public int deleteMallMemberMoneyRecordById(Long id);

    /**
     * 批量删除会员金额记录
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteMallMemberMoneyRecordByIds(Long[] ids);
}
