package com.ruoyi.mall.controller;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.mall.domain.MallMemberMoneyRecord;
import com.ruoyi.mall.service.IMallMemberMoneyRecordService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 会员金额记录Controller
 * 
 * @author chang
 * @date 2021-11-25
 */
@RestController
@RequestMapping("/mall/mallMemberMoneyRecord")
public class MallMemberMoneyRecordController extends BaseController
{
    @Autowired
    private IMallMemberMoneyRecordService mallMemberMoneyRecordService;

    /**
     * 查询会员金额记录列表
     */
    @PreAuthorize("@ss.hasPermi('mall:mallMemberMoneyRecord:list')")
    @GetMapping("/list")
    public TableDataInfo list(MallMemberMoneyRecord mallMemberMoneyRecord)
    {
        startPage();
        List<MallMemberMoneyRecord> list = mallMemberMoneyRecordService.selectMallMemberMoneyRecordList(mallMemberMoneyRecord);
        return getDataTable(list);
    }

    /**
     * 导出会员金额记录列表
     */
    @PreAuthorize("@ss.hasPermi('mall:mallMemberMoneyRecord:export')")
    @Log(title = "会员金额记录", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(MallMemberMoneyRecord mallMemberMoneyRecord)
    {
        List<MallMemberMoneyRecord> list = mallMemberMoneyRecordService.selectMallMemberMoneyRecordList(mallMemberMoneyRecord);
        ExcelUtil<MallMemberMoneyRecord> util = new ExcelUtil<MallMemberMoneyRecord>(MallMemberMoneyRecord.class);
        return util.exportExcel(list, "会员金额记录数据");
    }

    /**
     * 获取会员金额记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('mall:mallMemberMoneyRecord:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(mallMemberMoneyRecordService.selectMallMemberMoneyRecordById(id));
    }

    /**
     * 新增会员金额记录
     */
    @PreAuthorize("@ss.hasPermi('mall:mallMemberMoneyRecord:add')")
    @Log(title = "会员金额记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody MallMemberMoneyRecord mallMemberMoneyRecord)
    {
        return toAjax(mallMemberMoneyRecordService.insertMallMemberMoneyRecord(mallMemberMoneyRecord));
    }

    /**
     * 修改会员金额记录
     */
    @PreAuthorize("@ss.hasPermi('mall:mallMemberMoneyRecord:edit')")
    @Log(title = "会员金额记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody MallMemberMoneyRecord mallMemberMoneyRecord)
    {
        return toAjax(mallMemberMoneyRecordService.updateMallMemberMoneyRecord(mallMemberMoneyRecord));
    }

    /**
     * 删除会员金额记录
     */
    @PreAuthorize("@ss.hasPermi('mall:mallMemberMoneyRecord:remove')")
    @Log(title = "会员金额记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(mallMemberMoneyRecordService.deleteMallMemberMoneyRecordByIds(ids));
    }
}
